@@ -11,7 +11,8 @@ readable_status = {NodeState.RUNNING: "Running",
 
 class Printer(object):
     _formats = {"nodeimage": "image %(name)s (id = %(id)s)",
-            "nodesize": "size %(name)s (id=%(id)s, ram=%(ram)s, disk=%(disk)s bandwidth=%(bandwidth)s)"}
+            "nodesize": "size %(name)s (id=%(id)s, ram=%(ram)s, disk=%(disk)s bandwidth=%(bandwidth)s)",
+            "rackspacesharedipgroup": "IP group %(name)s (id = %(id)s, servers = %(servers)s)"}
 
     @classmethod
     def do(self, thing, format=None):
@@ -62,3 +63,11 @@ class Printer(object):
         else:
             fmt = "%(id)s\t%(name)s\t%(ip)s\t%(rstatus)s\n"
         sys.stdout.write(fmt % values)
+
+    @classmethod
+    def _print_nodelocation(self, thing, format=None):
+        values = thing.__dict__.copy()
+
+        fmt = "%(id)s\t%(name)s\t%(country)s\n"
+
+        sys.stdout.write(fmt % values)
